@@ -1,4 +1,7 @@
+"""Initialize this class to define request-rates for limiter
+"""
 from enum import Enum
+
 from .exceptions import ImmutableClassProperty
 
 
